"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const sf_plugins_core_1 = require("@salesforce/sf-plugins-core");
const ConfigAction_1 = require("../../lib/actions/ConfigAction");
const ConfigWriter_1 = require("../../lib/writers/ConfigWriter");
const ConfigViewer_1 = require("../../lib/viewers/ConfigViewer");
const CodeAnalyzerConfigFactory_1 = require("../../lib/factories/CodeAnalyzerConfigFactory");
const EnginePluginsFactory_1 = require("../../lib/factories/EnginePluginsFactory");
const messages_1 = require("../../lib/messages");
const LogEventListener_1 = require("../../lib/listeners/LogEventListener");
const ProgressEventListener_1 = require("../../lib/listeners/ProgressEventListener");
const ConfigModel_1 = require("../../lib/models/ConfigModel");
const Display_1 = require("../../lib/Display");
class ConfigCommand extends sf_plugins_core_1.SfCommand {
    // We don't need the `--json` output for this command.
    static enableJsonFlag = false;
    static summary = (0, messages_1.getMessage)(messages_1.BundleName.ConfigCommand, 'command.summary');
    static description = (0, messages_1.getMessage)(messages_1.BundleName.ConfigCommand, 'command.description');
    static examples = (0, messages_1.getMessages)(messages_1.BundleName.ConfigCommand, 'command.examples');
    // TODO: UN-HIDE WHEN COMMAND IS READY
    static hidden = true;
    static flags = {
        workspace: sf_plugins_core_1.Flags.string({
            summary: (0, messages_1.getMessage)(messages_1.BundleName.ConfigCommand, 'flags.workspace.summary'),
            description: (0, messages_1.getMessage)(messages_1.BundleName.ConfigCommand, 'flags.workspace.description'),
            char: 'w',
            multiple: true,
            delimiter: ',',
            // TODO: UN-HIDE WHEN ASSOCIATED FEATURES ARE IMPLEMENTED
            hidden: true
        }),
        'rule-selector': sf_plugins_core_1.Flags.string({
            summary: (0, messages_1.getMessage)(messages_1.BundleName.ConfigCommand, 'flags.rule-selector.summary'),
            description: (0, messages_1.getMessage)(messages_1.BundleName.ConfigCommand, 'flags.rule-selector.description'),
            char: 'r',
            multiple: true,
            delimiter: ',',
            default: ["Recommended"],
            // TODO: UN-HIDE WHEN ASSOCIATED FEATURES ARE IMPLEMENTED
            hidden: true
        }),
        'config-file': sf_plugins_core_1.Flags.file({
            summary: (0, messages_1.getMessage)(messages_1.BundleName.ConfigCommand, 'flags.config-file.summary'),
            description: (0, messages_1.getMessage)(messages_1.BundleName.ConfigCommand, 'flags.config-file.description'),
            char: 'c',
            exists: true,
            // TODO: UN-HIDE WHEN ASSOCIATED FEATURES ARE IMPLEMENTED
            hidden: true
        }),
        'output-file': sf_plugins_core_1.Flags.string({
            summary: (0, messages_1.getMessage)(messages_1.BundleName.ConfigCommand, 'flags.output-file.summary'),
            description: (0, messages_1.getMessage)(messages_1.BundleName.ConfigCommand, 'flags.output-file.description'),
            char: 'f'
        })
    };
    async run() {
        this.warn('This command is still a work-in-progress. Currently it can only generate a fixed config file.');
        const parsedFlags = (await this.parse(ConfigCommand)).flags;
        const dependencies = this.createDependencies(parsedFlags['output-file']);
        const action = ConfigAction_1.ConfigAction.createAction(dependencies);
        await action.execute(parsedFlags);
    }
    createDependencies(outputFile) {
        const uxDisplay = new Display_1.UxDisplay(this, this.spinner);
        const modelGeneratorFunction = (rawConfig, ruleSelection) => {
            return ConfigModel_1.DummyConfigModel.fromSelection(rawConfig, ruleSelection);
        };
        const dependencies = {
            configFactory: new CodeAnalyzerConfigFactory_1.CodeAnalyzerConfigFactoryImpl(),
            pluginsFactory: new EnginePluginsFactory_1.EnginePluginsFactoryImpl(),
            logEventListeners: [new LogEventListener_1.LogEventDisplayer(uxDisplay)],
            progressEventListeners: [new ProgressEventListener_1.RuleSelectionProgressSpinner(uxDisplay)],
            modelGenerator: modelGeneratorFunction,
            viewer: new ConfigViewer_1.ConfigRawYamlViewer(uxDisplay)
        };
        if (outputFile) {
            dependencies.writer = ConfigWriter_1.ConfigFileWriter.fromFile(outputFile);
        }
        return dependencies;
    }
}
exports.default = ConfigCommand;
//# sourceMappingURL=config.js.map