"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogEventLogger = exports.LogEventDisplayer = void 0;
const code_analyzer_core_1 = require("@salesforce/code-analyzer-core");
class LogEventDisplayer {
    display;
    constructor(display) {
        this.display = display;
    }
    listen(codeAnalyzer) {
        // Set up listeners
        codeAnalyzer.onEvent(code_analyzer_core_1.EventType.LogEvent, (e) => this.handleEvent('Core', e));
        codeAnalyzer.onEvent(code_analyzer_core_1.EventType.EngineLogEvent, (e) => this.handleEvent(e.engineName, e));
    }
    stopListening() {
        // Intentional no-op, because no cleanup is required.
    }
    handleEvent(source, event) {
        // We've arbitrarily decided to log only events of type "Info" or higher, to avoid potentially flooding the CLI
        // with a ton of noisy statements from other engines. At some point in the future, we may make this configurable.
        if (event.logLevel > code_analyzer_core_1.LogLevel.Info) {
            return;
        }
        const formattedMessage = `${source} [${formatTimestamp(event.timestamp)}]: ${event.message}`;
        switch (event.logLevel) {
            case code_analyzer_core_1.LogLevel.Error:
                this.display.displayError(formattedMessage);
                return;
            case code_analyzer_core_1.LogLevel.Warn:
                this.display.displayWarning(formattedMessage);
                return;
            case code_analyzer_core_1.LogLevel.Info:
                this.display.displayInfo(formattedMessage);
                return;
        }
    }
}
exports.LogEventDisplayer = LogEventDisplayer;
class LogEventLogger {
    logWriter;
    constructor(logWriter) {
        this.logWriter = logWriter;
    }
    listen(codeAnalyzer) {
        codeAnalyzer.onEvent(code_analyzer_core_1.EventType.LogEvent, (e) => this.handleEvent('Core', e));
        codeAnalyzer.onEvent(code_analyzer_core_1.EventType.EngineLogEvent, (e) => this.handleEvent(e.engineName, e));
    }
    stopListening() {
        this.logWriter.closeLog();
    }
    handleEvent(source, event) {
        // For now, we've decided to log every event type. If it turns out that we're flooding the logs with useless noise,
        // we can change that. And regardless, at some point we'll want this to be configurable.
        const formattedMessage = `[${event.timestamp.toISOString()}] ${code_analyzer_core_1.LogLevel[event.logLevel]} ${source} - ${event.message}\n`;
        this.logWriter.writeToLog(formattedMessage);
    }
}
exports.LogEventLogger = LogEventLogger;
function formatTimestamp(timestamp) {
    return `${timestamp.getHours()}:${timestamp.getMinutes()}:${timestamp.getSeconds()}`;
}
//# sourceMappingURL=LogEventListener.js.map