"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RuleTableViewer = exports.RuleDetailViewer = void 0;
const code_analyzer_core_1 = require("@salesforce/code-analyzer-core");
const StylingUtil_1 = require("../utils/StylingUtil");
const messages_1 = require("../messages");
class AbstractRuleViewer {
    display;
    constructor(display) {
        this.display = display;
    }
    view(rules) {
        if (rules.length === 0) {
            this.display.displayLog((0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.found-no-rules'));
        }
        else {
            this.display.displayLog((0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.found-rules', [rules.length]));
            this._view(rules);
        }
    }
}
class RuleDetailViewer extends AbstractRuleViewer {
    _view(rules) {
        const styledRules = [];
        for (let i = 0; i < rules.length; i++) {
            const rule = rules[i];
            const header = (0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.detail.header', [i + 1, rule.getName()]);
            const severity = rule.getSeverityLevel();
            const body = {
                engine: rule.getEngineName(),
                severity: `${severity.valueOf()} (${code_analyzer_core_1.SeverityLevel[severity]})`,
                type: code_analyzer_core_1.RuleType[rule.getType()],
                tags: rule.getTags().join(', '),
                resources: rule.getResourceUrls().join(', '),
                description: rule.getDescription()
            };
            const keys = ['severity', 'engine', 'type', 'tags', 'resources', 'description'];
            styledRules.push((0, StylingUtil_1.toStyledHeaderAndBody)(header, body, keys));
        }
        this.display.displayLog(styledRules.join('\n\n'));
    }
}
exports.RuleDetailViewer = RuleDetailViewer;
const TABLE_COLUMNS = {
    num: {
        header: (0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.table.num-column')
    },
    name: {
        header: (0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.table.name-column')
    },
    engine: {
        header: (0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.table.engine-column')
    },
    severity: {
        header: (0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.table.severity-column')
    },
    tag: {
        header: (0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.table.tag-column')
    }
};
class RuleTableViewer extends AbstractRuleViewer {
    _view(rules) {
        const ruleJsons = rules.map((rule, idx) => {
            const severity = rule.getSeverityLevel();
            return {
                num: idx + 1,
                name: rule.getName(),
                engine: rule.getEngineName(),
                severity: `${severity.valueOf()} (${code_analyzer_core_1.SeverityLevel[severity]})`,
                tag: rule.getTags().join(', ')
            };
        });
        this.display.displayTable(ruleJsons, TABLE_COLUMNS);
    }
}
exports.RuleTableViewer = RuleTableViewer;
//# sourceMappingURL=RuleViewer.js.map