"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResultsFileWriter = exports.CompositeResultsWriter = void 0;
const fs = __importStar(require("node:fs"));
const node_path_1 = __importDefault(require("node:path"));
const code_analyzer_core_1 = require("@salesforce/code-analyzer-core");
const messages_1 = require("../messages");
class CompositeResultsWriter {
    writers = [];
    constructor(writers) {
        this.writers = writers;
    }
    write(results) {
        this.writers.forEach(w => w.write(results));
    }
    static fromFiles(files) {
        return new CompositeResultsWriter(files.map(f => new ResultsFileWriter(f)));
    }
}
exports.CompositeResultsWriter = CompositeResultsWriter;
class ResultsFileWriter {
    file;
    format;
    constructor(file) {
        this.file = file;
        const ext = node_path_1.default.extname(file).toLowerCase();
        if (ext === '.csv') {
            this.format = code_analyzer_core_1.OutputFormat.CSV;
        }
        else if (['.html', '.htm'].includes(ext)) {
            this.format = code_analyzer_core_1.OutputFormat.HTML;
        }
        else if (ext === '.sarif' || file.toLowerCase().endsWith('.sarif.json')) {
            throw new Error('TODO: Support SARIF-type output');
            // Check for `.json` AFTER checking for `.sarif.json`!
        }
        else if (ext === '.json') {
            this.format = code_analyzer_core_1.OutputFormat.JSON;
        }
        else if (ext === '.junit' || file.toLowerCase().endsWith('.junit.xml')) {
            throw new Error('TODO: Support JUNIT-type output');
            // Check for `.xml` AFTER checking for `.junit.xml`!
        }
        else if (ext === '.xml') {
            this.format = code_analyzer_core_1.OutputFormat.XML;
        }
        else {
            throw new Error((0, messages_1.getMessage)(messages_1.BundleName.ResultsWriter, 'error.unrecognized-file-format', [file]));
        }
    }
    write(results) {
        fs.writeFileSync(this.file, results.toFormattedOutput(this.format));
    }
}
exports.ResultsFileWriter = ResultsFileWriter;
//# sourceMappingURL=ResultsWriter.js.map